/**
 * @author       Yannick Deubel (https://github.com/yandeu)
 * @copyright    Copyright (c) 2020 Yannick Deubel; Project Url: https://github.com/enable3d/enable3d
 * @license      {@link https://github.com/enable3d/enable3d/blob/master/LICENSE|LGPL-3.0}
 */
import Third from './third.js';
import * as Phaser from 'phaser';
import { Color } from 'three';
import { logger } from '@enable3d/common/dist/logger.js';
export class Scene3D extends Phaser.Scene {
    constructor(config) {
        super(config);
    }
    /** Access the Third Dimension */
    third;
    /**
     * It takes took long to setup the third dimension your self? Get started with warp speed by using this function.
     * @param features Pass the features you want to setup.
     */
    async warpSpeed(...features) {
        return await this.third.warpSpeed(...features);
    }
    haveSomeFun(numberOfElements = 20) {
        this.third.haveSomeFun(numberOfElements);
    }
    /** Place this in the init() function */
    requestThirdDimension() {
        logger('You do not need requestThirdDimension() anymore. Place accessThirdDimension() inside init() instead!');
    }
    clearThirdDimension() {
        // @ts-expect-error: this.third is not optional.
        for (const key in this.third)
            delete this.third[key];
        // @ts-expect-error: this.third is not optional.
        delete this.third;
    }
    /** Place this in the init() function */
    accessThirdDimension(config = {}) {
        this.clearThirdDimension();
        // create new third
        this.third = new Third(this, config);
        // set phaser background color to white
        // this.cameras.main.setBackgroundColor(0xffffff)
        // set phaser background color to transparent
        this.cameras.main.transparent = true;
        this.cameras.main.setBackgroundColor('rgba(0,0,0,0)');
        // set three.js background color to white
        this.third.scene.background = new Color('white');
    }
    /** Combines the 3 XR update methods */
    updateLoopXR(time, delta) {
        this.preUpdateXR(time, delta);
        this.updateXR(time, delta);
        this.postUpdateXR(time, delta);
    }
    /** Pre-Update the WebXR */
    preUpdateXR(_time, _delta) { }
    /** Update the WebXR. Use this to update your game loop in XR mode instead the normal update method provided by phaser.
     * It will overwrite the default Phaser clock and do some other things behind the scene for you. (The Phaser update loop will not run in WebXR mode!)
     */
    updateXR(_time, _delta) { }
    /** Post-Update the WebXR */
    postUpdateXR(_time, _delta) {
        if (this.third.isXrEnabled) {
            // overwrite the default phaser clock
            this.time.update(_time, _delta);
            // manually update the physics
            this.third.physics.update(_delta);
            // manually update physics debugger
            this.third.physics.updateDebugger();
            // manually update the mixers
            this.third.animationMixers.update(_delta);
        }
    }
}
//# sourceMappingURL=scene3d.js.map